@@ -94,6 +94,22 @@ test_flipAL =
                          ("e", ["d"])]
         ]
 
+test_uniq =
+    let f inp exp = TestCase $ exp @=? uniq inp in
+    [f ([]::[Int]) [],
+     f "asdf" "asdf",
+     f "aabbcc" "abc",
+     f "abcabc" "abc",
+     f "aaaaaa" "a",
+     f "aaaaaab" "ab",
+     f "111111111111111" "1",
+     f "baaaaaaaaa" "ba",
+     f "baaaaaaaaab" "ba",
+     f "aaacccdbbbefff" "acdbef",
+     f "foo" "fo",
+     f "15553344409" "153409",
+     f "Mississippi" "Misp"]
+
 test_trunc =
     let f len inp exp = TestCase $ exp @=? take len inp in
         [
@@ -144,6 +160,16 @@ test_alwaysElemRIndex =
         ,f 'f' ['f', 'b', 'f', 'f', 'b'] 3
         ]
 
+test_subIndex = 
+    let f item inp exp = TestCase $ exp @=? subIndex item inp in 
+        [f "foo" "asdfoobar" (Just 3)
+        ,f "foo" [] (Nothing)
+        ,f "" [] (Just 0)
+        ,f "" "asdf" (Just 0)
+        ,f "test" "asdftestbartest" (Just 4)
+        ,f [(1::Int), 2] [0, 5, 3, 2, 1, 2, 4] (Just 4)
+        ]
+
 test_fixedWidth =
     let f inplen inplist exp = TestLabel ((show inplen) ++ ", " ++
                                           (show inplist)) $ TestCase $
@@ -178,7 +204,18 @@ test_strToAL =
            "\"one\",1.0\n\"n\\nl\",2.0\n"
         ]
 
+test_spanList =
+    let f func inp exp = TestLabel (show inp) $ TestCase $ exp @=? spanList func inp
+        in
+          [f (contains "foo") "Testfoobar" ("Testf", "oobar"),
+           f (\_ -> True) "Testasdf" ("Testasdf", ""),
+           f (\_ -> False) "Testasdf" ("", "Testasdf"),
+           f (contains "foo") "" ("", ""),
+           f (contains "foo") "foo" ("f", "oo")]
+
+
 tests = TestList [TestLabel "delFromAL" (TestList test_delFromAL),
+                  TestLabel "uniq" (TestList test_uniq),
                   TestLabel "addToAL" (TestList test_addToAL),
                   TestLabel "split" (TestList test_split),
                   TestLabel "join" (TestList test_join),
@@ -190,7 +227,9 @@ tests = TestList [TestLabel "delFromAL" (TestList test_delFromAL),
                   TestLabel "replace" (TestList test_replace),
                   TestLabel "contains" (TestList test_contains),
                   TestLabel "strFromAL & strToAL" (TestList test_strToAL),
-                  TestLabel "fixedWidth" (TestList test_fixedWidth)]
+                  TestLabel "fixedWidth" (TestList test_fixedWidth),
+                  TestLabel "subIndex" (TestList test_subIndex),
+                  TestLabel "spanList" (TestList test_spanList)]
 
 
 
