@@ -21,6 +21,7 @@ import Test.HUnit
 import qualified MIMETypestest
 import qualified Listtest
 import qualified FiniteMaptest
+import qualified Maptest
 import qualified AnyDBMtest
 import qualified Pathtest
 import qualified Strtest
@@ -38,6 +39,8 @@ import qualified HVIOtest
 import qualified HVFStest
 import qualified Timetest
 import qualified Str.CSVtest
+import qualified WildMatchtest
+import qualified Globtest
 
 test1 = TestCase ("x" @=? "x")
 
@@ -47,10 +50,13 @@ tests = TestList [TestLabel "test1" test1,
                  TestLabel "CSV" Str.CSVtest.tests,
                  TestLabel "Time" Timetest.tests,
                  TestLabel "FiniteMap" FiniteMaptest.tests,
+                 TestLabel "Map" Maptest.tests,
                  TestLabel "AnyDBM" AnyDBMtest.tests,
                  TestLabel "Path" Pathtest.tests,
+                 TestLabel "WildMatch" WildMatchtest.tests,
                  TestLabel "HVIO" HVIOtest.tests,
                  TestLabel "HVFS" HVFStest.tests,
+                 TestLabel "Glob" Globtest.tests,
                  TestLabel "MIMETypes" MIMETypestest.tests,
                  TestLabel "Bitstest" Bitstest.tests,
                  TestLabel "Network.FTP.Parser" Network.FTP.Parsertest.tests,
